@@ -1,9 +1,9 @@
 package Locale::CLDR::Collator;
 
 use version;
-our $VERSION = version->declare('v0.28.0');
+our $VERSION = version->declare('v0.28.4');
 
-use v5.10;
+use v5.10.1;
 use mro 'c3';
 use utf8;
 use if $^V ge v5.12.0, feature => 'unicode_strings';
@@ -11,8 +11,8 @@ use if $^V ge v5.12.0, feature => 'unicode_strings';
 use Unicode::Normalize('NFD');
 use Unicode::UCD qw( charinfo );
 use List::MoreUtils qw(pairwise);
-use Moose;
-
+use Moo;
+use Types::Standard qw(Str Int Maybe ArrayRef InstanceOf);
 with 'Locale::CLDR::CollatorBase';
 
 my $NUMBER_SORT_TOP = "\x{FD00}\x{0034}";
@@ -21,68 +21,68 @@ my $FIELD_SEPARATOR = "\x{0002}";
 
 has 'type' => (
 	is => 'ro',
-	isa => 'Str',
+	isa => Str,
 	default => 'standard',
 );
 
 has 'locale' => (
 	is => 'ro',
-	isa => 'Maybe[Locale::CLDR]',
+	isa => Maybe[InstanceOf['Locale::CLDR']],
 	default => undef,
 	predicate => 'has_locale',
 );
 
 has 'alternate' => (
 	is => 'ro',
-	isa => 'Str',
+	isa => Str,
 	default => 'noignore'
 );
 
 has 'backwards' => (
 	is => 'ro',
-	isa => 'Str',
+	isa => Str,
 	default => 'false',
 );
 
 has 'case_level' => (
 	is => 'ro',
-	isa => 'Str',
+	isa => Str,
 	default => 'false',
 );
 
 has 'case_ordering' => (
 	is => 'ro',
-	isa => 'Str',
+	isa => Str,
 	default => 'false',
 );
 
 has 'normalization' => (
 	is => 'ro',
-	isa => 'Str',
+	isa => Str,
 	default => 'false',
 );
 
 has 'numeric' => (
 	is => 'ro',
-	isa => 'Str',
+	isa => Str,
 	default => 'false',
 );
 
 has 'reorder' => (
 	is => 'ro',
-	isa => 'ArrayRef',
+	isa => ArrayRef,
 	default => sub { [] },
 );
 
 has 'strength' => (
 	is => 'ro',
-	isa => 'Int',
+	isa => Int,
 	default => 3,
 );
 
 has 'max_variable' => (
 	is => 'ro',
-	isa => 'Str',
+	isa => Str,
 	default => 'punct',
 );
 
@@ -164,7 +164,7 @@ sub generate_ce {
 	my $base;
 	
 	if ($character =~ /\p{Unified_Ideograph}/) {
-		if ($character =~ /\p{Block=CJK_Unified_Ideograph}/ || $character =~ /\p{Block=CJK_Compatibility_Ideographs}/) {
+		if ($character =~ /\p{Block=CJK_Unified_Ideographs}/ || $character =~ /\p{Block=CJK_Compatibility_Ideographs}/) {
 			$base = 0xFB40;
 		}
 		else {
@@ -264,8 +264,9 @@ sub _convert_digits_to_numbers {
 	return @numbers;
 }
 
-no Moose;
+no Moo;
 
 1;
 
 # vim: tabstop=4
+
