@@ -1,19 +1,20 @@
 package Locale::CLDR::Locales::En::Any;
 
 # This file auto generated
-#	on Wed  3 Feb 12:09:24 am GMT
+#	on Mon 14 Mar 12:09:30 am GMT
 
 use version;
 
-our $VERSION = version->declare('v0.28.3');
+our $VERSION = version->declare('v0.28.4');
 
 use v5.10.1;
 use mro 'c3';
 use if $^V ge v5.12.0, feature => 'unicode_strings';
 
-use Moose;
+use Moo;
 
 extends('Locale::CLDR::Locales::En');
 
-no Moose;
-__PACKAGE__->meta->make_immutable;
+no Moo;
+
+1;
