@@ -2,7 +2,7 @@ package Locale::CLDR::NumberFormatter;
 
 use version;
 
-our $VERSION = version->declare('v0.28.2');
+our $VERSION = version->declare('v0.28.4');
 
 
 use v5.10.1;
@@ -10,7 +10,7 @@ use mro 'c3';
 use utf8;
 use if $^V ge v5.12.0, feature => 'unicode_strings';
 
-use Moose::Role;
+use Moo::Role;
 
 sub format_number {
 	my ($self, $number, $format, $currency, $for_cash) = @_;
@@ -666,7 +666,7 @@ sub _get_algorithmic_number_format {
 	}
 }
 
-no Moose::Role;
+no Moo::Role;
 
 1;
 
